@@ -197,7 +197,7 @@ func TestBreaking_DeprecationWithProperSunset(t *testing.T) {
 	// only a non-breaking change detected
 	require.Equal(t, checker.EndpointDeprecatedId, errs[0].GetId())
 	require.Equal(t, checker.INFO, errs[0].GetLevel())
-	require.Equal(t, "endpoint deprecated", errs[0].GetUncolorizedText(checker.NewDefaultLocalizer()))
+	require.Contains(t, errs[0].GetUncolorizedText(checker.NewDefaultLocalizer()), "endpoint deprecated")
 }
 
 // CL: path operations that became deprecated
@@ -220,7 +220,7 @@ func TestApiDeprecated_DetectsDeprecatedOperations(t *testing.T) {
 	require.Equal(t, checker.EndpointDeprecatedId, e0.Id)
 	require.Equal(t, "GET", e0.Operation)
 	require.Equal(t, "/api/test", e0.Path)
-	require.Equal(t, "endpoint deprecated", e0.GetUncolorizedText(checker.NewDefaultLocalizer()))
+	require.Contains(t, e0.GetUncolorizedText(checker.NewDefaultLocalizer()), "endpoint deprecated")
 }
 
 // CL: path operations that were re-activated
@@ -243,7 +243,7 @@ func TestApiDeprecated_DetectsReactivatedOperations(t *testing.T) {
 	require.Equal(t, checker.EndpointReactivatedId, e0.Id)
 	require.Equal(t, "GET", e0.Operation)
 	require.Equal(t, "/api/test", e0.Path)
-	require.Equal(t, "endpoint reactivated", e0.GetUncolorizedText(checker.NewDefaultLocalizer()))
+	require.Contains(t, e0.GetUncolorizedText(checker.NewDefaultLocalizer()), "endpoint reactivated")
 }
 
 func TestBreaking_InvaidStability(t *testing.T) {
@@ -267,3 +267,122 @@ func TestBreaking_InvaidStability(t *testing.T) {
 	require.Equal(t, "failed to parse stability level: 'value is not one of draft, alpha, beta or stable: \"ga\"'", e0.GetUncolorizedText(checker.NewDefaultLocalizer()))
 	require.Equal(t, "../data/deprecation/invalid-stability.yaml", errs[0].GetSource())
 }
+
+// CL: message includes sunset details when endpoint deprecated with sunset date
+func TestApiDeprecated_MessageIncludesSunset(t *testing.T) {
+	s1, err := open(getDeprecationFile("base.yaml"))
+	require.NoError(t, err)
+
+	s2, err := open(getDeprecationFile("deprecated-future.yaml"))
+	require.NoError(t, err)
+
+	d, osm, err := diff.GetWithOperationsSourcesMap(diff.NewConfig(), s1, s2)
+	require.NoError(t, err)
+
+	errs := checker.CheckBackwardCompatibilityUntilLevel(singleCheckConfig(checker.APIDeprecationCheck), d, osm, checker.INFO)
+	require.NotEmpty(t, errs)
+	require.Len(t, errs, 1)
+
+	require.Equal(t, checker.EndpointDeprecatedId, errs[0].GetId())
+	require.Equal(t, "endpoint deprecated (sunset: 9999-08-10)", errs[0].GetUncolorizedText(checker.NewDefaultLocalizer()))
+}
+
+// CL: message includes both sunset and stability when endpoint deprecated with both
+func TestApiDeprecated_MessageIncludesSunsetAndStability(t *testing.T) {
+	s1, err := open(getDeprecationFile("base.yaml"))
+	require.NoError(t, err)
+
+	s2, err := open(getDeprecationFile("deprecated-future-beta-stability.yaml"))
+	require.NoError(t, err)
+
+	d, osm, err := diff.GetWithOperationsSourcesMap(diff.NewConfig(), s1, s2)
+	require.NoError(t, err)
+
+	errs := checker.CheckBackwardCompatibilityUntilLevel(singleCheckConfig(checker.APIDeprecationCheck), d, osm, checker.INFO)
+	require.NotEmpty(t, errs)
+	require.Len(t, errs, 1)
+
+	require.Equal(t, checker.EndpointDeprecatedId, errs[0].GetId())
+	require.Equal(t, "endpoint deprecated (sunset: 9999-08-10, stability: beta)", errs[0].GetUncolorizedText(checker.NewDefaultLocalizer()))
+}
+
+// CL: message has no details when endpoint deprecated without sunset or stability
+func TestApiDeprecated_MessageWithoutDetails(t *testing.T) {
+	s1, err := open(getDeprecationFile("base.yaml"))
+	require.NoError(t, err)
+
+	s2, err := open(getDeprecationFile("deprecated-no-sunset.yaml"))
+	require.NoError(t, err)
+
+	d, osm, err := diff.GetWithOperationsSourcesMap(diff.NewConfig(), s1, s2)
+	require.NoError(t, err)
+
+	errs := checker.CheckBackwardCompatibilityUntilLevel(singleCheckConfig(checker.APIDeprecationCheck), d, osm, checker.INFO)
+	require.NotEmpty(t, errs)
+	require.Len(t, errs, 1)
+
+	require.Equal(t, checker.EndpointDeprecatedId, errs[0].GetId())
+	require.Equal(t, "endpoint deprecated", errs[0].GetUncolorizedText(checker.NewDefaultLocalizer()))
+}
+
+// CL: message includes stability when endpoint deprecated with stability but no sunset
+func TestApiDeprecated_MessageIncludesStabilityOnly(t *testing.T) {
+	s1, err := open(getDeprecationFile("base-beta-stability.yaml"))
+	require.NoError(t, err)
+
+	s2, err := open(getDeprecationFile("deprecated-no-sunset-beta-stability.yaml"))
+	require.NoError(t, err)
+
+	d, osm, err := diff.GetWithOperationsSourcesMap(diff.NewConfig(), s1, s2)
+	require.NoError(t, err)
+
+	errs := checker.CheckBackwardCompatibilityUntilLevel(singleCheckConfig(checker.APIDeprecationCheck), d, osm, checker.INFO)
+	require.NotEmpty(t, errs)
+	require.Len(t, errs, 1)
+
+	require.Equal(t, checker.EndpointDeprecatedId, errs[0].GetId())
+	require.Equal(t, "endpoint deprecated (stability: beta)", errs[0].GetUncolorizedText(checker.NewDefaultLocalizer()))
+}
+
+// CL: deprecating an operation with a sunset date in RFC3339 format is properly parsed
+func TestBreaking_DeprecationWithRFC3339Sunset(t *testing.T) {
+	s1, err := open(getDeprecationFile("base.yaml"))
+	require.NoError(t, err)
+
+	s2, err := open(getDeprecationFile("deprecated-future.yaml"))
+	require.NoError(t, err)
+
+	// Use RFC3339 format (with time) instead of just date
+	sunsetDate := civil.DateOf(time.Now()).AddDays(10)
+	sunsetRFC3339 := time.Date(sunsetDate.Year, sunsetDate.Month, sunsetDate.Day, 12, 0, 0, 0, time.UTC).Format(time.RFC3339)
+	s2.Spec.Paths.Value("/api/test").Get.Extensions[diff.SunsetExtension] = toJson(t, sunsetRFC3339)
+
+	d, osm, err := diff.GetWithOperationsSourcesMap(diff.NewConfig(), s1, s2)
+	require.NoError(t, err)
+	c := singleCheckConfig(checker.APIDeprecationCheck).WithDeprecation(0, 10)
+	errs := checker.CheckBackwardCompatibilityUntilLevel(c, d, osm, checker.INFO)
+	require.Len(t, errs, 1)
+	// only a non-breaking change detected
+	require.Equal(t, checker.EndpointDeprecatedId, errs[0].GetId())
+	require.Equal(t, checker.INFO, errs[0].GetLevel())
+}
+
+// BC: deprecating an operation with invalid JSON sunset date is breaking
+func TestBreaking_DeprecationWithInvalidJsonSunset(t *testing.T) {
+	s1, err := open(getDeprecationFile("base.yaml"))
+	require.NoError(t, err)
+
+	s2, err := open(getDeprecationFile("deprecated-future.yaml"))
+	require.NoError(t, err)
+
+	// Use invalid JSON that can't be unmarshaled to a string
+	s2.Spec.Paths.Value("/api/test").Get.Extensions[diff.SunsetExtension] = json.RawMessage(`{"invalid": "object"}`)
+
+	d, osm, err := diff.GetWithOperationsSourcesMap(diff.NewConfig(), s1, s2)
+	require.NoError(t, err)
+	c := singleCheckConfig(checker.APIDeprecationCheck).WithDeprecation(0, 10)
+	errs := checker.CheckBackwardCompatibility(c, d, osm)
+	require.Len(t, errs, 1)
+	require.Equal(t, checker.APIDeprecatedSunsetParseId, errs[0].GetId())
+	require.Contains(t, errs[0].GetUncolorizedText(checker.NewDefaultLocalizer()), "failed to unmarshal sunset json")
+}
