@@ -139,7 +139,7 @@ func TestBreaking_ParameterDeprecationWithProperSunset(t *testing.T) {
 	// only a non-breaking change detected
 	require.Equal(t, checker.RequestParameterDeprecatedId, errs[0].GetId())
 	require.Equal(t, checker.INFO, errs[0].GetLevel())
-	require.Equal(t, "'query' request parameter 'id' was deprecated", errs[0].GetUncolorizedText(checker.NewDefaultLocalizer()))
+	require.Contains(t, errs[0].GetUncolorizedText(checker.NewDefaultLocalizer()), "'query' request parameter 'id' was deprecated")
 }
 
 // CL: parameters that became deprecated
@@ -162,7 +162,7 @@ func TestParameterDeprecated_DetectsDeprecated(t *testing.T) {
 	require.Equal(t, checker.RequestParameterDeprecatedId, e0.Id)
 	require.Equal(t, "GET", e0.Operation)
 	require.Equal(t, "/api/test", e0.Path)
-	require.Equal(t, "'query' request parameter 'id' was deprecated", e0.GetUncolorizedText(checker.NewDefaultLocalizer()))
+	require.Contains(t, e0.GetUncolorizedText(checker.NewDefaultLocalizer()), "'query' request parameter 'id' was deprecated")
 }
 
 // CL: parameters that were re-activated
@@ -185,5 +185,81 @@ func TestParameterDeprecated_DetectsReactivated(t *testing.T) {
 	require.Equal(t, checker.RequestParameterReactivatedId, e0.Id)
 	require.Equal(t, "GET", e0.Operation)
 	require.Equal(t, "/api/test", e0.Path)
-	require.Equal(t, "'query' request parameter 'id' was reactivated", e0.GetUncolorizedText(checker.NewDefaultLocalizer()))
+	require.Contains(t, e0.GetUncolorizedText(checker.NewDefaultLocalizer()), "'query' request parameter 'id' was reactivated")
+}
+
+// CL: message includes sunset details when parameter deprecated with sunset date
+func TestParameterDeprecated_MessageIncludesSunset(t *testing.T) {
+	s1, err := open(getParameterDeprecationFile("base.yaml"))
+	require.NoError(t, err)
+
+	s2, err := open(getParameterDeprecationFile("deprecated-future.yaml"))
+	require.NoError(t, err)
+
+	d, osm, err := diff.GetWithOperationsSourcesMap(diff.NewConfig(), s1, s2)
+	require.NoError(t, err)
+
+	errs := checker.CheckBackwardCompatibilityUntilLevel(singleCheckConfig(checker.RequestParameterDeprecationCheck), d, osm, checker.INFO)
+	require.NotEmpty(t, errs)
+	require.Len(t, errs, 1)
+
+	require.Equal(t, checker.RequestParameterDeprecatedId, errs[0].GetId())
+	require.Equal(t, "'query' request parameter 'id' was deprecated (sunset: 9999-08-10)", errs[0].GetUncolorizedText(checker.NewDefaultLocalizer()))
+}
+
+// CL: message includes both sunset and stability when parameter deprecated with both
+func TestParameterDeprecated_MessageIncludesSunsetAndStability(t *testing.T) {
+	s1, err := open(getParameterDeprecationFile("base-beta-stability.yaml"))
+	require.NoError(t, err)
+
+	s2, err := open(getParameterDeprecationFile("deprecated-future-beta-stability.yaml"))
+	require.NoError(t, err)
+
+	d, osm, err := diff.GetWithOperationsSourcesMap(diff.NewConfig(), s1, s2)
+	require.NoError(t, err)
+
+	errs := checker.CheckBackwardCompatibilityUntilLevel(singleCheckConfig(checker.RequestParameterDeprecationCheck), d, osm, checker.INFO)
+	require.NotEmpty(t, errs)
+	require.Len(t, errs, 1)
+
+	require.Equal(t, checker.RequestParameterDeprecatedId, errs[0].GetId())
+	require.Equal(t, "'query' request parameter 'id' was deprecated (sunset: 9999-08-10, stability: beta)", errs[0].GetUncolorizedText(checker.NewDefaultLocalizer()))
+}
+
+// CL: message has no details when parameter deprecated without sunset or stability
+func TestParameterDeprecated_MessageWithoutDetails(t *testing.T) {
+	s1, err := open(getParameterDeprecationFile("base.yaml"))
+	require.NoError(t, err)
+
+	s2, err := open(getParameterDeprecationFile("deprecated-no-sunset.yaml"))
+	require.NoError(t, err)
+
+	d, osm, err := diff.GetWithOperationsSourcesMap(diff.NewConfig(), s1, s2)
+	require.NoError(t, err)
+
+	errs := checker.CheckBackwardCompatibilityUntilLevel(singleCheckConfig(checker.RequestParameterDeprecationCheck), d, osm, checker.INFO)
+	require.NotEmpty(t, errs)
+	require.Len(t, errs, 1)
+
+	require.Equal(t, checker.RequestParameterDeprecatedId, errs[0].GetId())
+	require.Equal(t, "'query' request parameter 'id' was deprecated", errs[0].GetUncolorizedText(checker.NewDefaultLocalizer()))
+}
+
+// CL: message includes stability when parameter deprecated with stability but no sunset
+func TestParameterDeprecated_MessageIncludesStabilityOnly(t *testing.T) {
+	s1, err := open(getParameterDeprecationFile("base-beta-stability.yaml"))
+	require.NoError(t, err)
+
+	s2, err := open(getParameterDeprecationFile("deprecated-no-sunset-beta-stability.yaml"))
+	require.NoError(t, err)
+
+	d, osm, err := diff.GetWithOperationsSourcesMap(diff.NewConfig(), s1, s2)
+	require.NoError(t, err)
+
+	errs := checker.CheckBackwardCompatibilityUntilLevel(singleCheckConfig(checker.RequestParameterDeprecationCheck), d, osm, checker.INFO)
+	require.NotEmpty(t, errs)
+	require.Len(t, errs, 1)
+
+	require.Equal(t, checker.RequestParameterDeprecatedId, errs[0].GetId())
+	require.Equal(t, "'query' request parameter 'id' was deprecated (stability: beta)", errs[0].GetUncolorizedText(checker.NewDefaultLocalizer()))
 }
