@@ -16,7 +16,7 @@ func TestResponsePropertyEnumValueRemoved(t *testing.T) {
 	s2, err := open("../data/checker/response_property_enum_added_base.yaml")
 	require.NoError(t, err)
 
-	s2.Spec.Components.Schemas["GroupView"].Value.Properties["data"].Value.Properties["typeEnum"].Value.Enum = []interface{}{"TYPE1"}
+	s2.Spec.Components.Schemas["GroupView"].Value.Properties["data"].Value.Properties["typeEnum"].Value.Enum = []any{"TYPE1"}
 
 	d, osm, err := diff.GetWithOperationsSourcesMap(diff.NewConfig(), s1, s2)
 	require.NoError(t, err)
@@ -40,7 +40,7 @@ func TestResponseWriteOnlyPropertyEnumValueRemoved(t *testing.T) {
 	s2, err := open("../data/checker/response_property_enum_added_base.yaml")
 	require.NoError(t, err)
 
-	s2.Spec.Components.Schemas["GroupView"].Value.Properties["data"].Value.Properties["writeOnlyEnum"].Value.Enum = []interface{}{"TYPE1"}
+	s2.Spec.Components.Schemas["GroupView"].Value.Properties["data"].Value.Properties["writeOnlyEnum"].Value.Enum = []any{"TYPE1"}
 
 	d, osm, err := diff.GetWithOperationsSourcesMap(diff.NewConfig(), s1, s2)
 	require.NoError(t, err)
