@@ -4,13 +4,12 @@ import (
 	"fmt"
 
 	"github.com/getkin/kin-openapi/openapi3"
-	"github.com/oasdiff/oasdiff/utils"
 )
 
 // CallbacksDiff describes the changes between a pair of callback objects: https://swagger.io/specification/#callback-object
 type CallbacksDiff struct {
-	Added    utils.StringList  `json:"added,omitempty" yaml:"added,omitempty"`
-	Deleted  utils.StringList  `json:"deleted,omitempty" yaml:"deleted,omitempty"`
+	Added    []string          `json:"added,omitempty" yaml:"added,omitempty"`
+	Deleted  []string          `json:"deleted,omitempty" yaml:"deleted,omitempty"`
 	Modified ModifiedCallbacks `json:"modified,omitempty" yaml:"modified,omitempty"`
 }
 
@@ -31,8 +30,8 @@ type ModifiedCallbacks map[string]*PathsDiff
 
 func newCallbacksDiff() *CallbacksDiff {
 	return &CallbacksDiff{
-		Added:    utils.StringList{},
-		Deleted:  utils.StringList{},
+		Added:    []string{},
+		Deleted:  []string{},
 		Modified: ModifiedCallbacks{},
 	}
 }
