@@ -6,13 +6,12 @@ import (
 	"regexp"
 
 	"github.com/getkin/kin-openapi/openapi3"
-	"github.com/oasdiff/oasdiff/utils"
 )
 
 // OperationsDiff describes the changes between a pair of operation objects (https://swagger.io/specification/#operation-object) of two path item objects
 type OperationsDiff struct {
-	Added    utils.StringList   `json:"added,omitempty" yaml:"added,omitempty"`
-	Deleted  utils.StringList   `json:"deleted,omitempty" yaml:"deleted,omitempty"`
+	Added    []string           `json:"added,omitempty" yaml:"added,omitempty"`
+	Deleted  []string           `json:"deleted,omitempty" yaml:"deleted,omitempty"`
 	Modified ModifiedOperations `json:"modified,omitempty" yaml:"modified,omitempty"`
 }
 
@@ -29,8 +28,8 @@ func (operationsDiff *OperationsDiff) Empty() bool {
 
 func newOperationsDiff() *OperationsDiff {
 	return &OperationsDiff{
-		Added:    utils.StringList{},
-		Deleted:  utils.StringList{},
+		Added:    []string{},
+		Deleted:  []string{},
 		Modified: ModifiedOperations{},
 	}
 }
