@@ -4,13 +4,12 @@ import (
 	"fmt"
 
 	"github.com/getkin/kin-openapi/openapi3"
-	"github.com/oasdiff/oasdiff/utils"
 )
 
 // SecuritySchemesDiff describes the changes between a pair of sets of security scheme objects: https://swagger.io/specification/#security-scheme-object
 type SecuritySchemesDiff struct {
-	Added    utils.StringList        `json:"added,omitempty" yaml:"added,omitempty"`
-	Deleted  utils.StringList        `json:"deleted,omitempty" yaml:"deleted,omitempty"`
+	Added    []string                `json:"added,omitempty" yaml:"added,omitempty"`
+	Deleted  []string                `json:"deleted,omitempty" yaml:"deleted,omitempty"`
 	Modified ModifiedSecuritySchemes `json:"modified,omitempty" yaml:"modified,omitempty"`
 }
 
@@ -30,8 +29,8 @@ type ModifiedSecuritySchemes map[string]*SecuritySchemeDiff
 
 func newSecuritySchemesDiff() *SecuritySchemesDiff {
 	return &SecuritySchemesDiff{
-		Added:    utils.StringList{},
-		Deleted:  utils.StringList{},
+		Added:    []string{},
+		Deleted:  []string{},
 		Modified: ModifiedSecuritySchemes{},
 	}
 }
