@@ -2,14 +2,13 @@ package diff
 
 import (
 	"github.com/getkin/kin-openapi/openapi3"
-	"github.com/oasdiff/oasdiff/utils"
 )
 
 // ServersDiff describes the changes between a pair of sets of encoding objects: https://swagger.io/specification/#server-object
 type ServersDiff struct {
-	Added    utils.StringList `json:"added,omitempty" yaml:"added,omitempty"`
-	Deleted  utils.StringList `json:"deleted,omitempty" yaml:"deleted,omitempty"`
-	Modified ModifiedServers  `json:"modified,omitempty" yaml:"modified,omitempty"`
+	Added    []string        `json:"added,omitempty" yaml:"added,omitempty"`
+	Deleted  []string        `json:"deleted,omitempty" yaml:"deleted,omitempty"`
+	Modified ModifiedServers `json:"modified,omitempty" yaml:"modified,omitempty"`
 }
 
 // ModifiedServers is map of server names to their respective diffs
@@ -28,8 +27,8 @@ func (diff *ServersDiff) Empty() bool {
 
 func newServersDiff() *ServersDiff {
 	return &ServersDiff{
-		Added:    utils.StringList{},
-		Deleted:  utils.StringList{},
+		Added:    []string{},
+		Deleted:  []string{},
 		Modified: ModifiedServers{},
 	}
 }
