@@ -985,19 +985,19 @@ func TestMerge_EnumContained(t *testing.T) {
 					&openapi3.SchemaRef{
 						Value: &openapi3.Schema{
 							Type: &openapi3.Types{"object"},
-							Enum: []interface{}{"1", nil, 1},
+							Enum: []any{"1", nil, 1},
 						},
 					},
 					&openapi3.SchemaRef{
 						Value: &openapi3.Schema{
 							Type: &openapi3.Types{"object"},
-							Enum: []interface{}{"1"},
+							Enum: []any{"1"},
 						},
 					},
 				},
 			}})
 	require.NoError(t, err)
-	require.ElementsMatch(t, []interface{}{"1"}, merged.Enum)
+	require.ElementsMatch(t, []any{"1"}, merged.Enum)
 }
 
 // enum merge fails if the intersection of enum values is empty.
@@ -1009,13 +1009,13 @@ func TestMerge_EnumNoIntersection(t *testing.T) {
 					&openapi3.SchemaRef{
 						Value: &openapi3.Schema{
 							Type: &openapi3.Types{"object"},
-							Enum: []interface{}{"1", nil},
+							Enum: []any{"1", nil},
 						},
 					},
 					&openapi3.SchemaRef{
 						Value: &openapi3.Schema{
 							Type: &openapi3.Types{"object"},
-							Enum: []interface{}{"2"},
+							Enum: []any{"2"},
 						},
 					},
 				},
@@ -1618,9 +1618,9 @@ func TestMerge_AdditionalProperties_False(t *testing.T) {
 	apFalse := false
 	apTrue := true
 
-	var firstPropEnum []interface{}
-	var secondPropEnum []interface{}
-	var thirdPropEnum []interface{}
+	var firstPropEnum []any
+	var secondPropEnum []any
+	var thirdPropEnum []any
 
 	firstPropEnum = append(firstPropEnum, "1", "5", "3")
 	secondPropEnum = append(secondPropEnum, "1", "8", "7")
@@ -1689,9 +1689,9 @@ func TestMerge_AdditionalProperties_False(t *testing.T) {
 func TestMerge_AdditionalProperties_True(t *testing.T) {
 	apTrue := true
 
-	var firstPropEnum []interface{}
-	var secondPropEnum []interface{}
-	var thirdPropEnum []interface{}
+	var firstPropEnum []any
+	var secondPropEnum []any
+	var thirdPropEnum []any
 
 	firstPropEnum = append(firstPropEnum, "1", "5", "3")
 	secondPropEnum = append(secondPropEnum, "1", "8", "7")
@@ -1928,3 +1928,186 @@ func loadSpec(t *testing.T, path string) *openapi3.T {
 	require.NoError(t, err)
 	return doc
 }
+
+// Test for issue #710: identical oneOf groups in allOf should be deduplicated
+// instead of producing a cartesian product
+func TestMerge_IdenticalOneOfGroups(t *testing.T) {
+	// Create two allOf subschemas with identical oneOf groups
+	oneOfA := &openapi3.SchemaRef{
+		Ref: "#/components/schemas/A",
+		Value: &openapi3.Schema{
+			Type:     &openapi3.Types{"object"},
+			Required: []string{"propA"},
+		},
+	}
+	oneOfB := &openapi3.SchemaRef{
+		Ref: "#/components/schemas/B",
+		Value: &openapi3.Schema{
+			Type:     &openapi3.Types{"object"},
+			Required: []string{"propB"},
+		},
+	}
+
+	merged, err := allof.Merge(
+		openapi3.SchemaRef{
+			Value: &openapi3.Schema{
+				AllOf: openapi3.SchemaRefs{
+					&openapi3.SchemaRef{
+						Value: &openapi3.Schema{
+							Type: &openapi3.Types{"object"},
+							OneOf: openapi3.SchemaRefs{
+								oneOfA,
+								oneOfB,
+							},
+						},
+					},
+					&openapi3.SchemaRef{
+						Value: &openapi3.Schema{
+							Type: &openapi3.Types{"object"},
+							OneOf: openapi3.SchemaRefs{
+								oneOfA,
+								oneOfB,
+							},
+						},
+					},
+				},
+			}})
+
+	require.NoError(t, err)
+	// Without the fix, this would produce 4 oneOf items (cartesian product)
+	// With the fix, identical oneOf groups are deduplicated, resulting in 2 items
+	require.Len(t, merged.OneOf, 2, "identical oneOf groups should be deduplicated, not produce cartesian product")
+}
+
+// Test that oneOf groups with same pointer references are deduplicated
+func TestMerge_SamePointerOneOfGroups(t *testing.T) {
+	// Create shared inline schemas (same pointer)
+	inlineA := &openapi3.SchemaRef{
+		Value: &openapi3.Schema{
+			Type:     &openapi3.Types{"object"},
+			Required: []string{"propA"},
+		},
+	}
+	inlineB := &openapi3.SchemaRef{
+		Value: &openapi3.Schema{
+			Type:     &openapi3.Types{"object"},
+			Required: []string{"propB"},
+		},
+	}
+
+	merged, err := allof.Merge(
+		openapi3.SchemaRef{
+			Value: &openapi3.Schema{
+				AllOf: openapi3.SchemaRefs{
+					&openapi3.SchemaRef{
+						Value: &openapi3.Schema{
+							Type: &openapi3.Types{"object"},
+							OneOf: openapi3.SchemaRefs{
+								inlineA,
+								inlineB,
+							},
+						},
+					},
+					&openapi3.SchemaRef{
+						Value: &openapi3.Schema{
+							Type: &openapi3.Types{"object"},
+							OneOf: openapi3.SchemaRefs{
+								inlineA,
+								inlineB,
+							},
+						},
+					},
+				},
+			}})
+
+	require.NoError(t, err)
+	// Same pointer references should be deduplicated
+	require.Len(t, merged.OneOf, 2, "oneOf groups with same pointer references should be deduplicated")
+}
+
+// Test that oneOf groups with refs in different order are still deduplicated (tests sorting)
+func TestMerge_OneOfGroupsReversedOrder(t *testing.T) {
+	oneOfA := &openapi3.SchemaRef{
+		Ref: "#/components/schemas/A",
+		Value: &openapi3.Schema{
+			Type: &openapi3.Types{"object"},
+		},
+	}
+	oneOfB := &openapi3.SchemaRef{
+		Ref: "#/components/schemas/B",
+		Value: &openapi3.Schema{
+			Type: &openapi3.Types{"object"},
+		},
+	}
+
+	merged, err := allof.Merge(
+		openapi3.SchemaRef{
+			Value: &openapi3.Schema{
+				AllOf: openapi3.SchemaRefs{
+					&openapi3.SchemaRef{
+						Value: &openapi3.Schema{
+							Type: &openapi3.Types{"object"},
+							OneOf: openapi3.SchemaRefs{
+								oneOfA, // A first
+								oneOfB,
+							},
+						},
+					},
+					&openapi3.SchemaRef{
+						Value: &openapi3.Schema{
+							Type: &openapi3.Types{"object"},
+							OneOf: openapi3.SchemaRefs{
+								oneOfB, // B first (reversed order)
+								oneOfA,
+							},
+						},
+					},
+				},
+			}})
+
+	require.NoError(t, err)
+	// Groups with same refs in different order should be deduplicated after sorting
+	require.Len(t, merged.OneOf, 2, "oneOf groups with same refs in different order should be deduplicated")
+}
+
+// Test different oneOf groups are not deduplicated
+func TestMerge_DifferentOneOfGroups(t *testing.T) {
+	merged, err := allof.Merge(
+		openapi3.SchemaRef{
+			Value: &openapi3.Schema{
+				AllOf: openapi3.SchemaRefs{
+					&openapi3.SchemaRef{
+						Value: &openapi3.Schema{
+							Type: &openapi3.Types{"object"},
+							OneOf: openapi3.SchemaRefs{
+								&openapi3.SchemaRef{
+									Ref: "#/components/schemas/A",
+									Value: &openapi3.Schema{
+										Type:     &openapi3.Types{"object"},
+										Required: []string{"propA"},
+									},
+								},
+							},
+						},
+					},
+					&openapi3.SchemaRef{
+						Value: &openapi3.Schema{
+							Type: &openapi3.Types{"object"},
+							OneOf: openapi3.SchemaRefs{
+								&openapi3.SchemaRef{
+									Ref: "#/components/schemas/B",
+									Value: &openapi3.Schema{
+										Type:     &openapi3.Types{"object"},
+										Required: []string{"propB"},
+									},
+								},
+							},
+						},
+					},
+				},
+			}})
+
+	require.NoError(t, err)
+	// Different oneOf groups should produce cartesian product (1 * 1 = 1 in this case)
+	require.Len(t, merged.OneOf, 1)
+}
