@@ -1,14 +1,22 @@
 package utils
 
+import (
+	"maps"
+	"slices"
+)
+
 // StringSet is a set of string values
 type StringSet map[string]struct{}
 
-func (stringSet StringSet) ToStringList() StringList {
-	result := make(StringList, len(stringSet))
-	i := 0
-	for s := range stringSet {
-		result[i] = s
-		i++
+func (stringSet StringSet) ToStringList() []string {
+	return slices.Collect(maps.Keys(stringSet))
+}
+
+// StringSetFromSlice creates a StringSet from a string slice
+func StringSetFromSlice(list []string) StringSet {
+	result := make(StringSet, len(list))
+	for _, s := range list {
+		result[s] = struct{}{}
 	}
 	return result
 }
